@@ -37,6 +37,9 @@ class SimpleJsonResultPacker(AbstractResultPacker):
         }
 
     def unpack(self, data, **kwargs):
+        if isinstance(data, (str, bytes)):
+            data = json.loads(data)
+
         if data["success"]:
             return data["result"]
         else:
