@@ -355,7 +355,6 @@ class decode_encrypted_data(ApiviewDecorator):
         self.encrypted_data_fieldname = encrypted_data_fieldname
 
     def main(self, _django_apiview_request, func):
-        request = _django_apiview_request.request
         privatekey = self.privatekey or getattr(settings, self.server_rsa_privatekey_filedname, None)
         encrypted_password = _django_apiview_request.data.get(self.encrypted_password_fieldname, "")
         encrypted_data = _django_apiview_request.data.get(self.encrypted_data_fieldname, "")
@@ -375,3 +374,22 @@ def safe_apiview(packer_class=SafeJsonResultPacker, **kwargs):
             ],
         extra_parameters=kwargs,
         )
+
+
+class check_aclkey(ApiviewDecorator):
+
+    def __init__(self, aclkey=None, aclkey_field_name="aclkey"):
+        self.aclkey_field_name = aclkey_field_name
+        self.aclkey = aclkey or settings.DJANGO_APIVIEW_ACLKEY
+    
+    def main(self, _django_apiview_request, func):
+        aclkey = _django_apiview_request.data[self.aclkey_field_name]
+        if not self._check_aclkey(aclkey):
+            raise bizerror.AppAuthFailed()
+        return super().main(_django_apiview_request, func)
+
+    def _check_aclkey(self, aclkey):
+        if callable(self.aclkey):
+            return self.aclkey() == aclkey
+        else:
+            return self.aclkey == aclkey
